- New IPG clusters
- Don't have them labelled
- Plug into HiGlass and have associated Scatter plot

- Compare new clusters with those selected from _trans_

- 4DN demo is a good starting point
- Getting whatever is up and running.
